//Change working directory/load data

//////////////////////
//Major models
//////////////////////

//Open dataset
clear
use "technocrats_replication.dta"

//Summary statistics: Web Appendix, Table A1
estpost sum TG_alt TG t_alt t_alt2 t_alt3 after_elections  scandal econ_recession_3y tot_power_pres ENPP polar_dalton_cmp misery
esttab using descriptives.rtf, replace cells("mean(fmt(2)) sd(fmt(2)) min(fmt(2)) max(fmt(2))") varlabels(`e(labels)') nonumber nomtitle noobs label 
mdesc TG_alt TG t_alt t_alt2 t_alt3 after_elections scandal econ_recession_3y tot_power_pres ENPP polar_dalton_cmp misery

//Multiple imputation
xtset country_N cabinet_no
mi set flong
mi register imputed scandal econ_recession_3y growth_3y polar_dalton_cmp ENPP tot_power_pres misery
set seed 12345
mi impute chained (pmm, knn(5)) scandal econ_recession_3y growth_3y polar_dalton_cmp ENPP tot_power_pres misery = TG_alt c.t_alt##c.t_alt##c.t_alt after_elections i.country_N, add(30) burnin(100) force

//Table 1, Model A1
mi estimate, post cmdok: firthlogit TG_alt after_elections t_alt t_alt2 t_alt3
outreg using "TG_alt_results.doc", replace starlevels(10 5 1) se

//Table 1, Model A2
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal t_alt t_alt2 t_alt3
outreg using "TG_alt_results.doc", merge starlevels(10 5 1) se

//Table 1, Model A3
mi estimate, post cmdok: firthlogit TG_alt after_elections econ_recession_3y t_alt t_alt2 t_alt3
outreg using "TG_alt_results.doc", merge starlevels(10 5 1) se

//Table 1, Model A4
mi estimate, post cmdok saving(miest, replace): firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3
outreg using "TG_alt_results.doc", merge starlevels(10 5 1) se

//Web Appendix, Table A3
mimrgns, at(scandal = 0 econ_recession_3y = 0) asobserved expression(exp(predict(xb))/(1+exp(predict(xb)))) 
mimrgns, at(scandal = 1 econ_recession_3y = 0) asobserved expression(exp(predict(xb))/(1+exp(predict(xb)))) 
mimrgns, at(scandal = 0 econ_recession_3y = 1) asobserved expression(exp(predict(xb))/(1+exp(predict(xb)))) 
mimrgns, at(scandal = 1 econ_recession_3y = 1) asobserved expression(exp(predict(xb))/(1+exp(predict(xb)))) 

mi estimate, post cmdok saving(miest, replace): firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3

//Get predictions for each observation
mi predictnl p = predict(xb) using miest, ci(ci5 ci95)
gen prob = exp(p) / (1 + exp(p))
gen prob_5 = exp(ci5) / (1 + exp(ci5)) 
gen prob_95 = exp(ci95) / (1 + exp(ci95)) 
gen se1 = abs(prob - prob_5) / 1.96
gen se2 = abs(prob - prob_95) / 1.96

//Get highest and lowest probabilities: Web Appendix, Table A2
egen rank_prob = rank(prob) if TG_alt == 0 & _mi_m == 0
sort rank_prob
list rank_prob cabinet_name election_date country_name if rank_prob < 25
list prob rank_prob cabinet_name election_date country_name if rank_prob > 420 & rank_prob != . 

//Scandal effect: calculate alternative probability and effect of scandal
gen scandal_save = scandal
replace scandal = 2 if scandal == 1
replace scandal = 1 if scandal == 0
replace scandal = 1 if scandal == 0.5
replace scandal = 0 if scandal == 2
mi predict p2 using miest 
gen prob_scandal = exp(p2) / (1 + exp(p2)) 
replace scandal = scandal_save
gen effect_scandal = abs(prob_scandal - prob)
egen effect_scandal_mean = mean(abs(prob - prob_scandal))
egen effect_scandal_max = max(abs(prob - prob_scandal))

//Recession effect: calculate alternative probability and effect of recession
gen econ_save = econ_recession_3y
replace econ_recession_3y = 2 if econ_recession_3y == 0
replace econ_recession_3y = 0 if econ_recession_3y == 1
replace econ_recession_3y = 1 if econ_recession_3y == 2
mi predict p3 using miest
gen prob_recession = exp(p3) / (1 + exp(p3)) 
replace econ_recession_3y = econ_save
gen effect_recession = abs(prob_recession - prob)
egen effect_recession_mean = mean(abs(prob - prob_recession))
egen effect_recession_max = max(abs(prob - prob_recession))

//Graph of scandal effects: Figure 3A
graph dot (mean) prob_scandal (mean) prob if effect_scandal > 0.25 & scandal_miss == 0, over(cabinet_name, sort(prob) descending label(labsize(vsmall))) cw ndots(30) legend(order(2 "Prediction observed values" 1 "Prediction scandal change") size(vsmall) region(lcolor(black)) bmargin(vsmall) ring(0)) scheme(lean2) xsize(14.2) ysize(20) ytitle("Predicted probability of technocrat-led government", size(small))
graph save "effect_scandal_cabinets", replace
graph export "effect_scandal_cabinets.png", replace height(2000)

//Graph of scandal effects: Figure 3B
graph dot (mean) prob_recession (mean) prob if effect_recession > 0.25  & recession_miss == 0, over(cabinet_name, sort(prob) descending label(labsize(vsmall))) cw ndots(30) legend(order(2 "Prediction observed values" 1 "Prediction recession change") size(vsmall) region(lcolor(black)) bmargin(vsmall) ring(0)) scheme(lean2) xsize(14.2) ysize(20) ytitle("Predicted probability of technocrat-led government", size(small))
graph save "effect_recession_cabinets", replace
graph export "effect_recession_cabinets.png", replace height(2000)

//Investigate dynamics
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3 
mimrgns, at(t_alt = 1 t_alt2 = 1 t_alt3 = 1) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file1, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3
mimrgns, at(t_alt = 2 t_alt2 = 4 t_alt3 = 8) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file2, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3 
mimrgns, at(t_alt = 3 t_alt2 = 9 t_alt3 = 27) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file3, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3 
mimrgns, at(t_alt = 4 t_alt2 = 16 t_alt3 = 64) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file4, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3 
mimrgns, at(t_alt = 5 t_alt2 = 25 t_alt3 = 100) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file5, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3 
mimrgns, at(t_alt = 6 t_alt2 = 36 t_alt3 = 216) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file6, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3 
mimrgns, at(t_alt = 7 t_alt2 = 49 t_alt3 = 343) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file7, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3 
mimrgns, at(t_alt = 8 t_alt2 = 64 t_alt3 = 512) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file8, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3 
mimrgns, at(t_alt = 9 t_alt2 = 81 t_alt3 = 729) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file9, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3 
mimrgns, at(t_alt = 10 t_alt2 = 100 t_alt3 = 1000) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file10, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3
mimrgns, at(t_alt = 11 t_alt2 = 121 t_alt3 = 1331) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file11, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3
mimrgns, at(t_alt = 12 t_alt2 = 144 t_alt3 = 1728) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file12, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3 
mimrgns, at(t_alt = 13 t_alt2 = 169 t_alt3 = 2197) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file13, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3 
mimrgns, at(t_alt = 14 t_alt2 = 196 t_alt3 = 2744) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file14, replace)
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3
mimrgns, at(t_alt = 15 t_alt2 = 225 t_alt3 = 3375) expression(exp(predict(xb))/(1+exp(predict(xb)))) saving(file15, replace)

//Graph of dynamics: Figure 2
combomarginsplot file1 file2 file3 file4 file5 file6 file7 file8 file9 file10 file11 file12 file13 file14 file15, labels(5 10 15) scheme(lean2) recast(line) recastci(rline) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Cabinets since last technocratic cabinet (t)") ytitle("Predicted probability of" "technocratic government") xlabel(5 10 15) title("")
graph save "dynamics", replace
graph export "dynamics.png", replace height(2000)


//////////////////////
//Alternative models
//////////////////////

//Table 2, Model B1
mi estimate, post cmdok: firthlogit TG_alt after_elections tot_power_pres t_alt t_alt2 t_alt3
outreg using "TG_alt_results_alternatives.doc", replace starlevels(10 5 1) se

//Table 2, Model B2
mi estimate, post cmdok: firthlogit TG_alt after_elections ENPP t_alt t_alt2 t_alt3
outreg using "TG_alt_results_alternatives.doc", merge starlevels(10 5 1) se

//Table 2, Model B3
mi estimate, post cmdok: firthlogit TG_alt after_elections polar_dalton_cmp t_alt t_alt2 t_alt3
outreg using "TG_alt_results_alternatives.doc", merge starlevels(10 5 1) se

//Table 2, Model B4
mi estimate, post cmdok: firthlogit TG_alt after_elections tot_power_pres ENPP polar_dalton_cmp t_alt t_alt2 t_alt3
outreg using "TG_alt_results_alternatives.doc", merge starlevels(10 5 1) se


//////////////////////
//Robustness checks
//////////////////////

//Misery index: Table 3, Model R1
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal misery t_alt t_alt2 t_alt3
outreg using "TG_alt_robustness.doc", replace starlevels(10 5 1) se

//Country random intercept: Table 3, Model R2
mi estimate, post cmdok: xtlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3, re
outreg using "TG_alt_robustness.doc", merge starlevels(10 5 1) se

//Open dataset
clear
use "technocrats_replication.dta"

//Resampling
set seed 54321
xtset, clear

//Bootstrapped SEs: Table 3, Model R3
bootstrap, cluster(country_N) idcluster(new_country) reps(500): firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3, iterate(50)
outreg using "TG_alt_robustness.doc", merge starlevels(10 5 1) se

//Jackknife test: Table 3, Model R4
xtset country_N cabinet_no
jackknife, cluster(country_N): firthlogit TG_alt after_elections scandal econ_recession_3y t_alt t_alt2 t_alt3
outreg using "TG_alt_robustness.doc", merge starlevels(10 5 1) se

//Multiple imputation
xtset country_N cabinet_no
mi set flong
mi register imputed scandal econ_recession_3y growth_3y
set seed 12345
mi impute chained (pmm, knn(5)) scandal econ_recession_3y = TG c.t##c.t##c.t after_elections i.country_N, add(30) burnin(100) force

//Pastorella's list of TGs: Table 3, Model R5
mi estimate, post cmdok: firthlogit TG after_elections scandal econ_recession_3y t t2 t3
outreg using "TG_alt_robustness.doc", merge starlevels(10 5 1) se


///////////////////////////
//Robustness Web Appendix
///////////////////////////

//Alternative economic crisis measures

//Open dataset
clear
use "technocrats_replication.dta"

//Multiple imputation
xtset country_N cabinet_no
mi set flong
mi register imputed scandal econ_recession_3y growth_3y econ_recession growth 
set seed 12345
mi impute chained (pmm, knn(5)) scandal econ_recession_3y growth_3y econ_recession growth = TG_alt c.t_alt##c.t_alt##c.t_alt after_elections i.country_N, add(30) burnin(100) force

//Web Appendix Table A4.1, Model R1
mi estimate, post cmdok saving(miest_appendix, replace): firthlogit TG_alt after_elections scandal econ_recession t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", replace starlevels(10 5 1) se

//Web Appendix Table A4.1, Model R2
mi estimate, post cmdok saving(miest_appendix, replace): firthlogit TG_alt after_elections scandal growth_3y t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se

//Web Appendix Table A4.1, Model R3
mi estimate, post cmdok saving(miest_appendix, replace): firthlogit TG_alt after_elections scandal growth t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se


//Alternative scandal measures

//Open dataset
clear
use "technocrats_replication.dta"

//Multiple imputation
xtset country_N cabinet_no
mi set flong
mi register imputed scandal scandal2 scandal_all scandal_wep scandal_es econ_recession_3y
set seed 12345
mi impute chained (pmm, knn(5)) scandal scandal2 scandal_all scandal_wep scandal_es econ_recession_3y = TG_alt c.t_alt##c.t_alt##c.t_alt after_elections i.country_N, add(30) burnin(100) force

//Web Appendix Table A4.1, Model R4
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal2 econ_recession_3y t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se

//Web Appendix Table A4.1, Model R5
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal_wep econ_recession_3y t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se

//Web Appendix Table A4.1, Model R6
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal_es econ_recession_3y t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se


//Alternative president-parliament power measures

//Open dataset
clear
use "technocrats_replication.dta"

//Multiple imputation
xtset country_N cabinet_no
mi set flong
mi register imputed median_perc
set seed 12345
mi impute chained (pmm, knn(5)) median_perc = TG_alt c.t_alt##c.t_alt##c.t_alt after_elections i.country_N, add(30) burnin(100) force

//Web Appendix Table A4.2, Model R7
mi estimate, post cmdok: firthlogit TG_alt after_elections median_perc t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se


//Interaction effects

//Open dataset
clear
use "technocrats_replication.dta"

//Generate interactions
gen int_scandal_econ = scandal * econ_recession_3y
gen int_scandal_pres = scandal * tot_power_pres
gen int_scandal_frag = scandal * ENPP
gen int_scandal_polar = scandal * polar_dalton_cmp
gen int_econ_pres = econ_recession_3y * tot_power_pres
gen int_econ_frag = econ_recession_3y * ENPP
gen int_econ_polar = econ_recession_3y * polar_dalton_cmp

//Multiple imputation
xtset country_N cabinet_no
mi set flong
mi register imputed scandal econ_recession_3y polar_dalton_cmp ENPP tot_power_pres int_scandal_* int_econ_*
set seed 12345
mi impute chained (pmm, knn(5)) scandal econ_recession_3y polar_dalton_cmp ENPP tot_power_pres int_scandal_* int_econ_* = TG_alt c.t_alt##c.t_alt##c.t_alt after_elections i.country_N, add(30) burnin(100) force

//Web Appendix Table A4.2, Model R8
mi estimate,  post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y tot_power_pres t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se

//Web Appendix Table A4.2, Model R9
mi estimate (scandal: _b[scandal]+ (0.15) * _b[int_scandal_econ]) (recession: _b[econ_recession_3y]+ (0.14) * _b[int_scandal_econ]),  post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y int_scandal_econ t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se

//Web Appendix Table A4.2, Model R10
mi estimate (scandal: _b[scandal]+ (2.08) * _b[int_scandal_pres]) (recession: _b[econ_recession_3y]+ (2.08) * _b[int_econ_pres]), post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y tot_power_pres int_scandal_pres int_econ_pres t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se

//Web Appendix Table A4.2, Model R11
mi estimate (scandal: _b[scandal]+ (4.10) * _b[int_scandal_frag]) (recession: _b[econ_recession_3y]+ (4.10) * _b[int_econ_frag]), post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y ENPP int_scandal_frag int_econ_frag t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se

//Web Appendix Table A4.2, Model R12
mi estimate (scandal: _b[scandal]+ (3.02) * _b[int_scandal_polar]) (recession: _b[econ_recession_3y]+ (3.02) * _b[int_econ_polar]), post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y polar_dalton_cmp int_scandal_polar int_econ_polar t_alt t_alt2 t_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se


//Alternative dynamics

//Open dataset
clear
use "technocrats_replication.dta"

//Multiple imputation
xtset country_N cabinet_no
mi set flong
mi register imputed scandal econ_recession_3y 
set seed 12345
mi impute chained (pmm, knn(5)) scandal econ_recession_3y = TG_alt DV_alt_lag after_elections i.country_N, add(30) burnin(100) force

//Web Appendix Table A4.2, Model R13
mi estimate, post cmdok: firthlogit TG_alt DV_alt_lag after_elections scandal econ_recession_3y 
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se


//Open dataset
clear
use "technocrats_replication.dta"

//Multiple imputation
xtset country_N cabinet_no
mi set flong
mi register imputed scandal econ_recession_3y
set seed 12345
mi impute chained (pmm, knn(5)) scandal econ_recession_3y = TG_alt c.t_days_alt##c.t_days_alt##c.t_days_alt after_elections i.country_N, add(30) burnin(100) force

//Web Appendix Table A4.2, Model R14
mi estimate, post cmdok: firthlogit TG_alt after_elections scandal econ_recession_3y t_days_alt t_days_alt2 t_days_alt3
outreg using "TG_alt_appendix.doc", merge starlevels(10 5 1) se


///////////////////////////////////
///////////////////////////////////
///////////////////////////////////

